'use strict';

var program = require('commander');
var path = require('path');
var validator = require('validator');
var camelCase = require('camel-case');
var assign = require('lodash.assign');
var isInProject = require('./libs/is-in-project.js')(process.cwd());
var inquirer = require('inquirer');
var prettyjson = require('prettyjson').render;
var get = require('lodash.get');
var chalk = require('chalk');
var partialRight = require('partial-right');
var omit = require('lodash.omit');
var delay = require('lodash.delay');
var stdoutContent = require('./libs/stdout-content');
var ui = new inquirer.ui.BottomBar();
var kill = require('tree-kill');
var updateNotifier = require('update-notifier');
var pkg = require('./package.json');

// notifikace pokud je v NPM novější verze aplikace
updateNotifier(pkg).notify();

require('autocmdr/lib/logger')(program);
require('autocmdr/lib/loader')(program);
require('autocmdr/lib/completion')(program);
require('autocmdr/lib/package')(program);
require('autocmdr/lib/config')(program);
require('autocmdr/lib/help')(program);

// inquiries
var inquiries = {
    createProject: require('./inquiries/create-project'),
    createRefill: require('./inquiries/create-refill'),
    createComponent: require('./inquiries/create-component'),
    exitBrowsersyncSession: require('./inquiries/exit-browsersync-session'),
    insideProject: require('./inquiries/inside-project'),
    installNpmModule: require('./inquiries/install-npm-module'),
    installRefill: require('./inquiries/install-refill'),
    outsideProject: require('./inquiries/outside-project'),
    projectConfig: require('./inquiries/project-config'),
    runBuildScript: require('./inquiries/run-build-script'),
    startBrowsersyncSession: require('./inquiries/start-browsersync-session'),
};

// tasks
var tasks = {
    startBrowsersyncProxy: require('./tasks/start-browsersync-proxy'),
};

function handleFailure(err) {
    kill(process.pid, 'SIGTERM');
    kill(process.pid, 'SIGINT');
}

function handleAction(actionInfo) {
    var action = get(actionInfo, 'action', '');
    var actionName = action.replace(/^(task|inquire)-/, '');

    if (actionName === 'exit-process') {
        kill(process.pid, 'SIGTERM');
        kill(process.pid, 'SIGINT');
        return;
    }

    var actionType = action.split('-').shift();
    var actionGroup = (actionType === 'task' ? tasks : actionType === 'inquire' ? inquiries : false);
    var actionFn = get(actionGroup, camelCase(actionName), false);
    var actionOpts = get(actionInfo, 'options', {});

    if (actionName === '' || actionType === '' || actionGroup === false || actionFn === false) {
        throw new Error('Nepovedlo se interpretovat požadovanou akci', actionInfo.action);
    }

    stdoutContent.divider();

    switch (actionType) {
        case 'inquire':
            actionFn(actionOpts).then(handleAction).catch(handleFailure);
            break;
        case 'task':
            actionFn(actionOpts).then(handleTask).catch(handleFailure);
            break;
    }
}

function handleTask(payload, logUi) {
    stdoutContent.divider();

    if ('resource' in payload) {
        payload.resource.then(function(res) {
            ui.log(res);
            res.stdout.pipe(ui.log);
        });
    }

    if ('action' in payload) {
        delay(partialRight(handleAction, omit(payload, 'resource')), 2000);
    }

}

if (isInProject) {
    handleAction({
        action: "inquire-inside-project"
    });
} else {
    handleAction({
        action: "inquire-outside-project"
    });
}

// var config = require('dotfile-config')();
// console.log(config.set({
//     owner: 'viktor.bezdek@gmail.com'
// }));
// console.log(config.get('owner'));

// program
//     .parse(process.argv);

// if (program.args.length < 1) {
//     console.log('No command specified. See \'feds-cli --help\':');
//     program.outputHelp();
//     process.exit(1);
// }
