/**
 * Konfigurace projektu
 * @return  {Promise} callback Promise s výsledky otázek
 */
module.exports = function(opts) {
    var inquirer = require('inquirer');
    var isLength = require('validator').isLength;
    var assign = require('lodash.assign');
    var slugify = require('../libs/slugify');
    var partialRight = require('partial-right');
    var omit = require('lodash.omit');

    var COMPONENT_TYPES = {
        "scss-komponenta": "create-scss-component",
        "zakladni-blok": "create-common-block",
        "obsahovy-blok": "create-content-block",
        "dynamicky-modul": "create-dynamic-module",
        "redux-store": "create-redux-store",
        "stranka": "create-page",
    };

    var questions = [{
        name: "componentType",
        message: "Druh komponenty",
        type: "list",
        choices: ["SCSS komponenta", "Základní blok", "Obsahový blok", "Dynamický modul", "Redux Store", "Stránka"],
        filter: function(str) {
            return COMPONENT_TYPES[slugify(str)];
        }
    }, {
        name: "componentName",
        message: "Jméno komponenty",
        type: "input",
        filter: function(str) {
            return slugify(str);
        },
        validate: function(input) {
            // TODO check jestli už v knihovně componentů není registrovaný jiný se stejným jménem
            return !isLength(input, 3) ? 'Jméno komponenty musí být dlouhé alespoň 3 znaky.' : true;
        }
    }];

    var inquiryResolver = function(answers, resolve) {
        resolve({
            action: 'task-' + answers.componentType,
            options: omit(assign(opts, answers), 'action')
        });
    };

    return new Promise(function(resolve, reject) {
        try {
            require('../libs/stdout-content').title('Vytvořit novou komponentu');
            inquirer.prompt(questions, partialRight(inquiryResolver, resolve));
        } catch (e) {
            reject(e);
        }
    });
}
