/**
 * Zjišťuje podrobnosti před vytvářením nového projektu
 * @return  {Promise} callback Promise s výsledky otázek
 */
module.exports = function(opts) {
    var inquirer = require('inquirer');
    var isLength = require('validator').isLength;
    var assign = require('lodash.assign');
    var slugify = require('../libs/slugify');
    var partialRight = require('partial-right');
    var omit = require('lodash.omit');

    var PROJECT_TYPES = {
        "web-s-nette-projekty": "create-boilerplate-web",
        "staticke-html-sablony": "create-boilerplate-static-site",
        "npm-modul": "create-boilerplate-npm-module",
        "riotjs-tag": "create-boilerplate-riotjs-tag"
    };

    var questions = [{
        name: "projectType",
        message: "Druh projektu",
        type: "list",
        choices: ["Web s Nette backendem", "Statické HTML šablony", "NPM modul", "RiotJS tag"], // , "Interaktivní prvky do iSaZe", "E-mailová šablona"
        filter: function(str) {
            return PROJECT_TYPES[slugify(str)];
        }
    },{
        name: "projectName",
        message: "Jméno projektu",
        type: "input",
        filter: function(str) {
            return slugify(str.toLowerCase());
        },
        validate: function(input) {
            return !isLength(input, 3) ? 'Jméno projektu musí být dlouhé alespoň 3 znaky.' : true;
        }
    }];

    var inquiryResolver = function(answers, resolve) {
        resolve({
            action: 'task-' + answers.projectType,
            options: omit(assign(opts, answers), 'action')
        });
    };

    return new Promise(function(resolve, reject) {
        try {
            require('../libs/stdout-content').title('Vytvořit nový projekt');
            inquirer.prompt(questions, partialRight(inquiryResolver, resolve));
        } catch (e) {
            reject(e);
        }
    });
}
