/**
 * Konfigurace projektu
 * @return  {Promise} callback Promise s výsledky otázek
 */
module.exports = function(opts) {
    var inquirer = require('inquirer');
    var isEmail = require('validator').isEmail;
    var isURL = require('validator').isURL;
    var assign = require('lodash.assign');
    var partialRight = require('partial-right');
    var omit = require('lodash.omit');

    var questions = [{
        name: "ownerEmail",
        message: "Zadej svůj pracovní email",
        type: "input",
        filter: function(str) {
            return str.toLowerCase();
        },
        validate: function(input) {
            if (!isEmail(input)) {
                return 'Zadej správně emailovou adresu.';
            } else {
                if (input.indexOf('siteone') === -1) {
                    return 'Zadej svůj pracovní (firemní) email.';
                } else {
                    return true;
                }
            }
        }
    }, {
        name: "devURL",
        message: "Na jaké URL běží tato workcopy",
        type: "input",
        filter: function(str) {
            return str.toLowerCase();
        },
        validate: function(input) {
            if (!isURL(input)) {
                return 'Zadej správně URL workcopy.';
            }
            return true;
        }
    }];

    var inquiryResolver = function(answers, resolve) {
        resolve({
            action: 'task-config-project',
            options: omit(assign(opts, answers), 'action')
        });
    };

    return new Promise(function(resolve, reject) {
        try {
            require('../libs/stdout-content').title('Nastavení projektu');
            inquirer.prompt(questions, partialRight(inquiryResolver, resolve));
        } catch (e) {
            reject(e);
        }
    });
}
