/**
 * Zjišťuje podrobnosti před vytvářením browser sync proxy
 * @return  {Promise} callback Promise s výsledky otázek
 */
module.exports = function(opts) {
    var inquirer = require('inquirer');
    var assign = require('lodash.assign');
    var partialRight = require('partial-right');
    var omit = require('lodash.omit');

    var isURL = partialRight(require('validator').isURL, {
        protocols: ['https', 'http'],
        require_protocol: true,
        require_tld: false
    });

    var questions = [{
        name: "targetURL",
        message: "URL webu",
        type: "input",
        filter: function(str) {
            return str.toLowerCase();
        },
        validate: function(input) {
            return isURL(input);
        }
    }];

    var inquiryResolver = function(answers, resolve) {
        resolve({
            action: 'task-start-browsersync-proxy',
            options: omit(assign(opts, answers), 'action')
        });
    };

    return new Promise(function(resolve, reject) {
        try {
            require('../libs/stdout-content').title('BrowserSync session');
            require('../libs/stdout-content').description('BrowserSync umožňuje synchronizované prohlížení (testování) webových projektů pomocí proxy, která přes socket server kopíruje operace provedené v prohližeči do ostatních relací.');
            inquirer.prompt(questions, partialRight(inquiryResolver, resolve));
        } catch (e) {
            reject(e);
        }
    });
}
